ZeroForm

Trait ZeroForm 

pub trait ZeroForm {
    // Required method
    fn to_zero_form(&self) -> Ex;
}
Types that can be viewed as an equation expr = 0.

Implemented for Ex (the expression itself is the zero form) and Equation (lhs - rhs), so solver entry points accept either.

use symplex::prelude::*;
use symplex::polysys::ZeroForm;

let ctx = Context::new();
let x = ctx.symbol("x");
let eq = Equation::new(&x + 1, ctx.int(3));
assert_eq!(format!("{}", eq.to_zero_form()), "x - 2");

Required Methods

fn to_zero_form(&self) -> Ex

Return the expression that equals zero when the equation holds.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T: ZeroForm> ZeroForm for &T

Implementors