pub type BoxOutcome = Outcome<BoxCertificate, BoxUnknown>;Expand description
Result of prove_nonnegative_on_box: an Outcome with a
BoxCertificate or a BoxUnknown.
Aliased Type
pub enum BoxOutcome {
Proved(BoxCertificate),
#[non_exhaustive] Refuted {
point: Vec<(Expr<Numeric>, Ratio<BigInt>)>,
value: Ratio<BigInt>,
param_value: Option<Ratio<BigInt>>,
},
Unknown(BoxUnknown),
}Variants
Proved(BoxCertificate)
A certificate, re-verified with exact arithmetic before it was returned: the goal is non-negative on the set.
#[non_exhaustive]Refuted
The goal is negative at this exact point of the set — the claim is false.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
Unknown(BoxUnknown)
Neither a certificate nor a counterexample was found within the
search; U says how far the search went. Never a wrong Proved.